@@ -17,6 +17,11 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#else
+#define PREFIX "/usr"
+#endif
 
 #include "install.h"
 
@@ -40,7 +45,7 @@ int main(int argc, char **argv)
 	// specify data for About dialog
 	TDEAboutData* about = new TDEAboutData("kdpkg-install", I18N_NOOP("kdpkg-install"), "");
 
-	about->setProgramLogo( TQImage("/usr/share/icons/hicolor/32x32/apps/kdpkg.png") );
+	about->setProgramLogo( TQImage( PREFIX "/share/icons/hicolor/32x32/apps/kdpkg.png") );
 	about->setShortDescription( I18N_NOOP("Frontend for dpkg.") );
 	about->setLicense(TDEAboutData::License_GPL_V2);
    about->setHomepage("http://trinity.pearsoncomputing.net");
@@ -50,8 +55,6 @@ int main(int argc, char **argv)
 	about->addAuthor("Timothy Pearson (Trinity Project)", I18N_NOOP("Developer"), "kb9vqf@pearsoncomputing.net", "http://trinity.pearsoncomputing.net");
 	about->addAuthor("Fabian Würtz (xadras)", I18N_NOOP("Developer"), "xadras@sidux.com", "http://linux.wuertz.org/");
 
-
-
 	TDECmdLineArgs::init(argc, argv, about);
 	TDECmdLineArgs::addCmdLineOptions( options );
 
